#pragma once

#include "window.h"
#include "unassignable.h"

namespace rov2
{

/*! Base class for an icon */
class CIcon : public CClickable, public CUnassignable
{
public:
  /*! Gets the icon handle
  \return The icon handle */
  inline const tIconHandle Handle() const { return m_ihIcon; }

  /*! Destroys this icon */
  virtual ~CIcon();

protected:
  /*! Only a derived class can construct icons*/
  CIcon();

  /*! The window to which this icon is attached */
  CWindow* m_pwWindow;

  /*! The icon handle */
  tIconHandle m_ihIcon;
}; // i

class CCreatedIcon : public CIcon
{
public:
  /*! Creates an icon based on an icon creation block
  \param rkicbBlock The icon creation block
  \param pwWindow The window to assign it to
  \param bRegister Whether to register the icon with the window or not
  */
  CCreatedIcon(tIconCreateBlock& ricbBlock, CWindow* pwWindow, bool bRegister = true);

  /*! Destroys the icon */
  ~CCreatedIcon();

private:
  bool m_bRegistered;
};

}